@@ -1,9 +1,9 @@
 from datetime import datetime
 from enum import Enum
-from typing import AnyStr, Dict, List, Optional
+from typing import Dict, List, Optional
 from uuid import UUID
 
-from pydantic import BaseModel
+from serenity_types.utils.serialization import CamelModel
 
 
 class VolModel(Enum):
@@ -38,7 +38,28 @@ class StrikeType(Enum):
     """
 
 
-class VolatilitySurfaceDefinition(BaseModel):
+class DiscountingMethod(Enum):
+    """
+    In valuation, the strategy to use for getting the forward price for Black-Scholes.
+    """
+
+    CURVE = "CURVE"
+    """
+    Extract a discount factor from the yield curve provided and discount the spot price.
+    """
+
+    FUTURES = "FUTURES"
+    """
+    Use a futures price or its proxy as the forward price.
+    """
+
+    DISABLED = "DISABLED"
+    """
+    Assume a zero risk-free rate (Deribit approach)
+    """
+
+
+class VolatilitySurfaceDefinition(CamelModel):
     """
     A uniquely-identified set of VS parameters for fitting a VolatilitySurface.
     """
@@ -59,6 +80,11 @@ class VolatilitySurfaceDefinition(BaseModel):
     Strike representation used for this surface, e.g. ABSOLUTE or LOG_MONEYNESS.
     """
 
+    discounting_method: DiscountingMethod
+    """
+    Discounting method used for this surface, e.g. CURVE or FUTURES or DISABLED.
+    """
+
     underlier_asset_id: UUID
     """
     The linked asset for this surface, e.g. for a Bitcoin volatility surface, this is BTC.
@@ -70,7 +96,7 @@ class VolatilitySurfaceDefinition(BaseModel):
     """
 
 
-class VolatilitySurfaceAvailability(BaseModel):
+class VolatilitySurfaceAvailability(CamelModel):
     """
     Information about version availability for a given volsurface definition.
     """
@@ -80,13 +106,13 @@ class VolatilitySurfaceAvailability(BaseModel):
     Description of the particular volsurface parameters that are available to load.
     """
 
-    build_times: List[datetime]
+    as_of_times: List[datetime]
     """
-    The list of all available build times in the requested window.
+    The list of all available as_of_times in the requested window.
     """
 
 
-class VolPoint(BaseModel):
+class VolPoint(CamelModel):
     """
     An individual IV input point.
     """
@@ -101,6 +127,11 @@ class VolPoint(BaseModel):
     The time to expiry for this point, expressed as a year fraction.
     """
 
+    strike_value: float
+    """
+    Value of strike for this point, unit defined by StrikeType.
+    """
+
     mark_price: float
     """
     The observed option premium used as input to the IV calculation.
@@ -122,7 +153,12 @@ class VolPoint(BaseModel):
     """
 
 
-class RawVolatilitySurface(BaseModel):
+class RawVolatilitySurface(CamelModel):
+    strike_type: StrikeType
+    """
+    Strike representation used for this surface, e.g. ABSOLUTE or LOG_MONEYNESS.
+    """
+
     spot_price: float
     """
     The observed spot price that went into the IV calculations.
@@ -134,7 +170,7 @@ class RawVolatilitySurface(BaseModel):
     """
 
 
-class InterpolatedVolatilitySurface(BaseModel):
+class InterpolatedVolatilitySurface(CamelModel):
     """
     A calibrated volatility surface with a dense grid of fitted vols. Each array
     is of equal length and corresponds to (x, y, z) for the mesh.
@@ -160,14 +196,20 @@ class InterpolatedVolatilitySurface(BaseModel):
     All fitted vols, the z-axis in the mesh.
     """
 
-    calibration_params: Dict[AnyStr, AnyStr]
+    input_params: Dict[str, object]
     """
-    Informational set of calibration paramters, e.g. the SVI parameters. May be empty and
-    keys will depend on the VolModel.
+    Informational set of input parameters, e.g. yield curves used for the forward. May be empty
+    and keys will depend on the configuration, e.g. DiscountingType.
+    """
+
+    calibration_params: Dict[float, Dict[str, float]]
+    """
+    Informational set of calibration parameters, e.g. the SVI parameters. Keying is time_to_expiry
+    expressed in year fractions to parameter set, where the parameter keys are VolModel-specific.
     """
 
 
-class VolatilitySurfaceVersion(BaseModel):
+class VolatilitySurfaceVersion(CamelModel):
     """
     A single version of a fitted volatility surface, with both the raw and interpolated content.
     """
